Remove debug yield statements
[urcu.git] / urcu.c
diff --git a/urcu.c b/urcu.c
index 9542b264a6dbf53d36d2fb63e7578b4e7ff2b2f5..018e09b8601b041621fc6f72afdaeb57839e895c 100644 (file)
--- a/urcu.c
+++ b/urcu.c
@@ -43,7 +43,9 @@ unsigned int __thread rand_yield;
 
 static struct reader_data *reader_data;
 static int num_readers, alloc_readers;
+#ifndef DEBUG_FULL_MB
 static int sig_done;
+#endif
 
 void internal_urcu_lock(void)
 {
@@ -77,36 +79,29 @@ static void switch_next_urcu_qparity(void)
 #ifdef DEBUG_FULL_MB
 static void force_mb_all_threads(void)
 {
-       mb();
+       smp_mb();
 }
 #else
 static void force_mb_all_threads(void)
 {
        struct reader_data *index;
        /*
* Ask for each threads to execute a mb() so we can consider the
         * compiler barriers around rcu read lock as real memory barriers.
         */
        if (!reader_data)
                return;
-       debug_yield_write();
        sig_done = 0;
-       debug_yield_write();
-       mb();   /* write sig_done before sending the signals */
-       debug_yield_write();
-       for (index = reader_data; index < reader_data + num_readers; index++) {
+       smp_mb();       /* write sig_done before sending the signals */
+       for (index = reader_data; index < reader_data + num_readers; index++)
                pthread_kill(index->tid, SIGURCU);
-               debug_yield_write();
-       }
        /*
         * Wait for sighandler (and thus mb()) to execute on every thread.
         * BUSY-LOOP.
         */
        while (sig_done < num_readers)
                barrier();
-       debug_yield_write();
-       mb();   /* read sig_done before ending the barrier */
-       debug_yield_write();
+       smp_mb();       /* read sig_done before ending the barrier */
 }
 #endif
 
@@ -133,13 +128,10 @@ void synchronize_rcu(void)
         * where new ptr points to. */
        /* Write new ptr before changing the qparity */
        force_mb_all_threads();
-       debug_yield_write();
 
        internal_urcu_lock();
-       debug_yield_write();
 
        switch_next_urcu_qparity();     /* 0 -> 1 */
-       debug_yield_write();
 
        /*
         * Must commit qparity update to memory before waiting for parity
@@ -147,13 +139,12 @@ void synchronize_rcu(void)
         * waiting forever while new readers are always accessing data (no
         * progress).
         */
-       mb();
+       smp_mb();
 
        /*
         * Wait for previous parity to be empty of readers.
         */
        wait_for_quiescent_state();     /* Wait readers in parity 0 */
-       debug_yield_write();
 
        /*
         * Must finish waiting for quiescent state for parity 0 before
@@ -161,10 +152,9 @@ void synchronize_rcu(void)
         * the writer waiting forever while new readers are always accessing
         * data (no progress).
         */
-       mb();
+       smp_mb();
 
        switch_next_urcu_qparity();     /* 1 -> 0 */
-       debug_yield_write();
 
        /*
         * Must commit qparity update to memory before waiting for parity
@@ -172,23 +162,20 @@ void synchronize_rcu(void)
         * waiting forever while new readers are always accessing data (no
         * progress).
         */
-       mb();
+       smp_mb();
 
        /*
         * Wait for previous parity to be empty of readers.
         */
        wait_for_quiescent_state();     /* Wait readers in parity 1 */
-       debug_yield_write();
 
        internal_urcu_unlock();
-       debug_yield_write();
 
        /* All threads should finish using the data referred to by old ptr
         * before decrementing their urcu_active_readers count */
        /* Finish waiting for reader threads before letting the old ptr being
         * freed. */
        force_mb_all_threads();
-       debug_yield_write();
 }
 
 void urcu_add_reader(pthread_t id)
@@ -256,7 +243,7 @@ void urcu_unregister_thread(void)
 #ifndef DEBUG_FULL_MB
 void sigurcu_handler(int signo, siginfo_t *siginfo, void *context)
 {
-       mb();
+       smp_mb();
        atomic_inc(&sig_done);
 }
 
@@ -77,36 +79,29 @@ static void switch_next_urcu_qparity(void)
        struct reader_data *index;
        /*
-        * Ask for each threads to execute a mb() so we can consider the
+        * Ask for each threads to execute a smp_mb() so we can consider the
         * compiler barriers around rcu read lock as real memory barriers.
         */
This page took 0.023752 seconds and 4 git commands to generate.